ChatKitUtils class

Constructors

ChatKitUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isDesktopOrWeb bool
判断当前平台是否为桌面端(macOS、Windows、Linux)或 Web 用于 UI 层进行平台分支判断,桌面端/Web 使用三栏布局等桌面化交互
no setter
isMobleClient bool
是否是移动端
no setter

Static Methods

conversationId(String targetId, NIMConversationType type) String?
getConversationTargetId(String conversationId) String

Constants

CONVERSATION_ID_SPLIT → const String