clearCache method
void
clearCache()
Clears all robot data, including any cached robot configuration token.
Implementation
void clearCache() {
_resetCache();
}
Clears all robot data, including any cached robot configuration token.
void clearCache() {
_resetCache();
}