MergedMessage class

合并消息

Constructors

MergedMessage({required String sessionId, required String sessionName, required String url, required String? md5, required int? depth, required List<MergeMessageAbstract> abstracts})
MergedMessage.fromMap(Map<String, dynamic> map)
factory

Properties

abstracts ↔ List<MergeMessageAbstract>
合并消息的摘要,用于在消息列表展示,默认三条
getter/setter pair
depth ↔ int?
合并消息的深度
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
md5 ↔ String?
合并消息文件的md5
getter/setter pair
messageId ↔ String?
合并消息的id,用于标识合并消息 通NIMMessage.uuid获取
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String
会话id
getter/setter pair
sessionName ↔ String
会话名称
getter/setter pair
url ↔ String
合并消息上传NOS后的url
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultMaxDepth → const int