MessageTranslationState class
Constructors
- MessageTranslationState({MessageTranslationInfo? translation, bool failed = false, MessageTranslationSource source = MessageTranslationSource.manual})
-
const
Properties
- failed → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → MessageTranslationSource
-
final
- translation → MessageTranslationInfo?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited