MessageVoiceToTextInfo class

Constructors

MessageVoiceToTextInfo({required String text, required int convertedAt, required String source})
const
MessageVoiceToTextInfo.fromMap(Map<String, dynamic> map)
factory

Properties

convertedAt int
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited