BotSubsessionListItem class

Constructors

BotSubsessionListItem({required BotSubsessionTopicContext context, required String title, required String summary, required int latestTime, bool showUnreadDot = false, int? highlightStart, int? highlightEnd})
const

Properties

context BotSubsessionTopicContext
final
hashCode int
The hash code for this object.
no setterinherited
highlightEnd int?
final
highlightStart int?
final
isPlaceholder bool
no setter
latestTime int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showUnreadDot bool
final
summary String
final
title String
final

Methods

copyWith({BotSubsessionTopicContext? context, String? title, String? summary, int? latestTime, bool? showUnreadDot, int? highlightStart, int? highlightEnd}) BotSubsessionListItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited