RecentForward class

Constructors

RecentForward(String sessionId, NIMConversationType sessionType)

Properties

friend ↔ ContactInfo?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String
getter/setter pair
sessionType ↔ NIMConversationType
getter/setter pair
team ↔ NIMTeam?
getter/setter pair
time ↔ int
getter/setter pair

Methods

getAvatar() → String?
getCount() → int
getName() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJsonArray(List jsonArray) → List<RecentForward>
toJsonList(List<RecentForward>? recentForwards) → List<Map<String, dynamic>>?