SearchDisplayLine class

A line displayed in a search result.

Constructors

SearchDisplayLine({required String text, required UserSearchField field, List<SearchMatchRange> matches = const [], bool isPrimary = false})
const

Properties

field UserSearchField
final
hashCode int
The hash code for this object.
no setterinherited
isPrimary bool
final
matches List<SearchMatchRange>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited