SearchMatchRange class

A matched UTF-16 range in a searchable field.

Constructors

SearchMatchRange({required int start, required int end, required UserSearchField field})
const

Properties

end int
final
field UserSearchField
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited