UserSearchResult<T> class

Immutable result returned by UserSearchService.

Constructors

UserSearchResult({required T value, required String accountId, required String primaryName, required UserSearchField primaryField, required List<SearchDisplayLine> lines})
const

Properties

accountId String
final
hashCode int
The hash code for this object.
no setterinherited
lines List<SearchDisplayLine>
final
primaryField UserSearchField
final
primaryName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited