UserSearchService class

Shared matching and result shaping rules for contacts and team members.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

contactFields(ContactInfo contact) Map<UserSearchField, String?>
Builds searchable fields for a contact.
Searches values using the supplied field and account projections.
teamMemberFields(UserInfoWithTeam member) Map<UserSearchField, String?>
Builds searchable fields for a team member.