utils/request_coordinator library

Classes

KeyedRequestCache<T>
Reuses an in-flight request and its recent result for the same key.
KeyedThrottledRequest<T>
Serializes requests per key and coalesces bursts without dropping a request that arrives after the current operation has started.

Typedefs

AsyncRequest<T> = Future<T> Function()