KeyedThrottledRequest<T> class

Serializes requests per key and coalesces bursts without dropping a request that arrives after the current operation has started.

Constructors

KeyedThrottledRequest({required Duration minInterval})

Properties

hashCode int
The hash code for this object.
no setterinherited
minInterval Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(String key, AsyncRequest<T> request) Future<T>
Runs request at most once per minInterval for key.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited