AIRobotManager class
用户级 AI 机器人管理 登录成功后分页拉取当前用户下所有机器人并缓存在内存中
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
robotCache
→ Map<
String, V2NIMUserAIBot> -
final
-
robotChanged
↔ Stream<
List< ?V2NIMUserAIBot> > -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAllRobotList(
) → List< V2NIMUserAIBot> -
getAllRobots(
) → Future< void> -
getRobotById(
String accid) → V2NIMUserAIBot? -
init(
) → void -
isRobot(
String? accid) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upsertRobot(
V2NIMUserAIBot bot) → void - Add or update a single AI robot in memory cache.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → AIRobotManager
-
final