MessageTranslationHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildTextTranslationContent(
String text, {String? serverExtension}) → MessageTranslationTextContent -
Splits text using structured mention ranges from
serverExtension. -
isSupportedLanguage(
String code) → bool -
languageName(
String code, String? localeLanguageCode) → String -
languageOf(
String code) → MessageTranslateLanguage -
mergeMessageTranslation(
String? localExtension, MessageTranslationInfo translation) → String -
messageIdentity(
NIMMessage message) → String -
parseMessageTranslation(
NIMMessage message) → MessageTranslationInfo?
Constants
-
defaultLanguages
→ const List<
MessageTranslateLanguage> - keyTranslation → const String
- logTag → const String