MessageTranslationInfo class

Constructors

MessageTranslationInfo({required String targetLanguage, String? sourceLanguage, required String text, required int translatedAt, required MessageTranslationSource source, bool hidden = false})
const
MessageTranslationInfo.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hidden bool
final
isValid bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source MessageTranslationSource
final
sourceLanguage String?
final
targetLanguage String
final
text String
final
translatedAt int
final

Methods

copyWith({bool? hidden}) MessageTranslationInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited