MessageVoiceToTextHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
mergeVoiceToText(
String? localExtension, MessageVoiceToTextInfo voiceToText) → String -
messageIdentity(
NIMMessage message) → String -
parseVoiceToText(
NIMMessage message) → MessageVoiceToTextInfo? -
resolveVoiceToTextState(
NIMMessage _, {MessageVoiceToTextState? memoryState}) → MessageVoiceToTextState? - Voice-to-text content is only visible during the current chat page.
Constants
- keyVoiceToText → const String
- logTag → const String