BotSubsessionTopicContext class
Constructors
- BotSubsessionTopicContext({required String conversationId, V2NIMTopic? topic, bool isPlaceholder = false, String placeholderTitle = '新会话', String? localKey})
-
const
Properties
- conversationId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPersisted → bool
-
no setter
- isPlaceholder → bool
-
final
- localKey → String?
-
final
- placeholderTitle → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topic → V2NIMTopic?
-
final
- topicKey → String
-
no setter
Methods
-
copyWith(
{String? conversationId, V2NIMTopic? topic, bool? isPlaceholder, String? placeholderTitle, String? localKey}) → BotSubsessionTopicContext -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited