UserSearchService class
Shared matching and result shaping rules for contacts and team members.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
contactFields(
ContactInfo contact) → Map< UserSearchField, String?> - Builds searchable fields for a contact.
-
search<
T> ({required Iterable< T> values, required Map<UserSearchField, String?> fieldsOf(T value), required String accountIdOf(T value), String query = '', List<UserSearchField> fieldOrder = teamFieldOrder}) → List<UserSearchResult< T> > -
Searches
valuesusing the supplied field and account projections. -
teamMemberFields(
UserInfoWithTeam member) → Map< UserSearchField, String?> - Builds searchable fields for a team member.
Constants
-
aiFieldOrder
→ const List<
UserSearchField> -
contactFieldOrder
→ const List<
UserSearchField> -
teamFieldOrder
→ const List<
UserSearchField>